/**
 * @license
 * Copyright 2017 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { OnDisconnect } from './onDisconnect';
import { TransactionResult } from './TransactionResult';
import { Query } from './Query';
import { Repo } from '../core/Repo';
import { Path } from '../core/util/Path';
import { Database } from './Database';
import { DataSnapshot } from './DataSnapshot';
export interface ReferenceConstructor {
    new (repo: Repo, path: Path): Reference;
}
export declare class Reference extends Query {
    then: Promise<Reference>['then'];
    catch: Promise<Reference>['catch'];
    /**
     * Call options:
     *   new Reference(Repo, Path) or
     *   new Reference(url: string, string|RepoManager)
     *
     * Externally - this is the firebase.database.Reference type.
     */
    constructor(repo: Repo, path: Path);
    /** @return {?string} */
    getKey(): string | null;
    child(pathString: string | Path): Reference;
    /** @return {?Reference} */
    getParent(): Reference | null;
    /** @return {!Reference} */
    getRoot(): Reference;
    /** @return {!Database} */
    databaseProp(): Database;
    set(newVal: unknown, onComplete?: (a: Error | null) => void): Promise<unknown>;
    update(objectToMerge: object, onComplete?: (a: Error | null) => void): Promise<unknown>;
    setWithPriority(newVal: unknown, newPriority: string | number | null, onComplete?: (a: Error | null) => void): Promise<unknown>;
    remove(onComplete?: (a: Error | null) => void): Promise<unknown>;
    transaction(transactionUpdate: (a: unknown) => unknown, onComplete?: (a: Error | null, b: boolean, c: DataSnapshot | null) => void, applyLocally?: boolean): Promise<TransactionResult>;
    setPriority(priority: string | number | null, onComplete?: (a: Error | null) => void): Promise<unknown>;
    push(value?: unknown, onComplete?: (a: Error | null) => void): Reference;
    onDisconnect(): OnDisconnect;
    get database(): Database;
    get key(): string | null;
    get parent(): Reference | null;
    get root(): Reference;
}
