/**
 * @license
 * Copyright 2017 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { FirebaseApp } from '@firebase/app-types';
import { FirebaseApp as FirebaseAppExp } from "@firebase/app";
import { Repo } from './Repo';
import { Database } from '../api/Database';
import { RepoInfo } from './RepoInfo';
import { FirebaseAuthInternalName } from '@firebase/auth-interop-types';
import { Provider } from '@firebase/component';
import { AuthTokenProvider } from './AuthTokenProvider';
/**
 * Intersection type that allows the SDK to be used from firebase-exp and
 * firebase v8.
 */
export declare type FirebaseAppLike = FirebaseApp | FirebaseAppExp;
/**
 * Creates and caches Repo instances.
 */
export declare class RepoManager {
    private repos_;
    /**
     * If true, new Repos will be created to use ReadonlyRestClient (for testing purposes).
     */
    private useRestClient_;
    static getInstance(): RepoManager;
    interrupt(): void;
    resume(): void;
    /**
     * Update an existing repo in place to point to a new host/port.
     */
    applyEmulatorSettings(repo: Repo, host: string, port: number): void;
    /**
     * This function should only ever be called to CREATE a new database instance.
     */
    databaseFromApp(app: FirebaseAppLike, authProvider: Provider<FirebaseAuthInternalName>, url?: string, nodeAdmin?: boolean): Database;
    /**
     * Remove the repo and make sure it is disconnected.
     *
     */
    deleteRepo(repo: Repo): void;
    /**
     * Ensures a repo doesn't already exist and then creates one using the
     * provided app.
     *
     * @param repoInfo The metadata about the Repo
     * @return The Repo object for the specified server / repoName.
     */
    createRepo(repoInfo: RepoInfo, app: FirebaseAppLike, authTokenProvider: AuthTokenProvider): Repo;
    /**
     * Forces us to use ReadonlyRestClient instead of PersistentConnection for new Repos.
     */
    forceRestClient(forceRestClient: boolean): void;
}
